@@ -65,7 +65,6 @@ def test_offline_fido(query):
 
 
 @pytest.mark.remote_data
-@pytest.mark.flaky(reruns=5)
 # Until we get more mocked, we can't really do this to online clients.
 # TODO: Hypothesis this again
 @pytest.mark.parametrize("query", [
@@ -111,7 +110,6 @@ def test_save_path(tmpdir):
 
 
 @pytest.mark.remote_data
-@pytest.mark.flaky(reruns=5)
 def test_save_path_pathlib(tmpdir):
     qr = Fido.search(a.Instrument('EVE'), a.Time("2016/10/01", "2016/10/02"), a.Level(0))
 
@@ -124,16 +122,6 @@ def test_save_path_pathlib(tmpdir):
         assert f"eve{os.path.sep}0" in f
 
 
-@pytest.mark.remote_data
-def test_save_path_cwd(tmpdir):
-    qr = Fido.search(a.Instrument('EVE'), a.Time("2016/10/01", "2016/10/02"), a.Level(0))
-
-    # Test when path is ./ for current working directory
-    os.chdir(tmpdir)  # move into temp directory
-    files = Fido.fetch(qr, path="./")
-    for f in files:
-        assert pathlib.Path.cwd().joinpath(f).exists()
-
 """
 Factory Tests
 """
@@ -180,6 +168,7 @@ def test_call_error():
     assert "'UnifiedDownloaderFactory' object is not callable" in str(excinfo.value)
 
 
+@pytest.mark.remote_data
 def test_multiple_match():
     """
     Using the builtin clients a multiple match is not possible so we create a
@@ -202,11 +191,11 @@ def test_multiple_match():
 
 @pytest.mark.remote_data
 def test_fetch():
-        qr = Fido.search(a.Instrument('EVE'),
-                         a.Time("2016/10/01", "2016/10/02"),
-                         a.Level(0))
-        res = Fido.fetch(qr)
-        assert isinstance(res, Results)
+    qr = Fido.search(a.Instrument('EVE'),
+                     a.Time("2016/10/01", "2016/10/02"),
+                     a.Level(0))
+    res = Fido.fetch(qr)
+    assert isinstance(res, Results)
 
 
 """
@@ -216,6 +205,7 @@ Use LYRA here because it does not use the internet to return results.
 """
 
 
+@pytest.mark.remote_data
 def test_unifiedresponse_slicing():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -223,6 +213,7 @@ def test_unifiedresponse_slicing():
     assert isinstance(results[0], UnifiedResponse)
 
 
+@pytest.mark.remote_data
 def test_unifiedresponse_slicing_reverse():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -239,6 +230,7 @@ def test_vso_unifiedresponse():
     assert isinstance(uresp, UnifiedResponse)
 
 
+@pytest.mark.remote_data
 def test_responses():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -249,6 +241,7 @@ def test_responses():
     assert i + 1 == len(results)
 
 
+@pytest.mark.remote_data
 def test_repr():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
@@ -262,24 +255,29 @@ def test_repr():
 def filter_queries(queries):
     return attr.and_(queries) not in queries
 
+
+@pytest.mark.remote_data
 def test_path():
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
 
     Fido.fetch(results, path="notapath/{file}")
 
+
+@pytest.mark.remote_data
 @skip_windows
 def test_path_read_only(tmp_path):
     results = Fido.search(
         a.Time("2012/1/1", "2012/1/5"), a.Instrument("lyra"))
 
     # chmod dosen't seem to work correctly on the windows CI
-    os.chmod(tmp_path, S_IREAD|S_IRGRP|S_IROTH)
+    os.chmod(tmp_path, S_IREAD | S_IRGRP | S_IROTH)
     # Check to see if it's actually read only before running the test
     if not os.access(tmp_path, os.W_OK):
         with pytest.raises(PermissionError):
             Fido.fetch(results, path=tmp_path / "{file}")
 
+
 @settings(deadline=50000)
 @given(st.tuples(offline_query(), offline_query()).filter(filter_queries))
 def test_fido_indexing(queries):
@@ -413,6 +411,7 @@ def test_mixed_retry_error():
         Fido.fetch([], Results())
 
 
+@pytest.mark.remote_data
 @mock.patch("sunpy.net.dataretriever.sources.goes.XRSClient.fetch",
             return_value=["hello"])
 def test_client_fetch_wrong_type(mock_fetch):
@@ -423,15 +422,6 @@ def test_client_fetch_wrong_type(mock_fetch):
     with pytest.raises(TypeError):
         Fido.fetch(qr)
 
-
-@pytest.mark.remote_data
-def test_unclosedSocket_warning():
-    with pytest.warns(None):
-        attrs_time = a.Time('2005/01/01 00:10', '2005/01/01 00:15')
-        result = Fido.search(attrs_time, a.Instrument('eit'))
-        Fido.fetch(result)
-
-
 @pytest.mark.remote_data
 def test_slice_jsoc():
     tstart = '2011/06/07 06:32:45'
