@@ -6,7 +6,6 @@ import copy
 import warnings
 from collections import OrderedDict
 
-import matplotlib.pyplot as plt
 import pandas as pd
 
 import astropy
@@ -141,6 +140,13 @@ class GenericTimeSeries:
         """
         return self.data.index
 
+    @property
+    def shape(self):
+        """
+        The shape of the data, a tuple (nrows, ncols).
+        """
+        return self.data.shape
+
     @property
     def time_range(self):
         """
@@ -217,6 +223,27 @@ class GenericTimeSeries:
         # Return a new TimeSeries with the given updated/added column.
         return self.__class__(data, meta, units)
 
+    def remove_column(self, colname):
+        """
+        Remove a column.
+
+        Parameters
+        ----------
+        colname : str
+            The heading of the column to remove.
+
+        Returns
+        -------
+        `sunpy.timeseries.TimeSeries`
+            A new `~sunpy.timeseries.TimeSeries`.
+        """
+        if colname not in self.columns:
+            raise ValueError(f'Given column name ({colname}) not in list of columns {self.columns}')
+        data = self.data.drop(colname, 'columns')
+        units = self.units.copy()
+        units.pop(colname)
+        return self.__class__(data, self.meta, units)
+
     def sort_index(self, **kwargs):
         """
         Returns a sorted version of a `~sunpy.timeseries.TimeSeries`. Generally
@@ -382,13 +409,15 @@ class GenericTimeSeries:
             If provided the image will be plotted on the given axes.
             Defaults to `None`, so the current axes will be used.
         **plot_args : `dict`, optional
-            Any additional plot arguments that should be used when plotting.
+            Additional plot keyword arguments that are handed to
+            :meth:`pandas.DataFrame.plot`.
 
         Returns
         -------
         axes : `~matplotlib.axes.Axes`
             The plot axes.
         """
+        import matplotlib.pyplot as plt
         # Get current axes
         if axes is None:
             axes = plt.gca()
@@ -409,6 +438,7 @@ class GenericTimeSeries:
         **kwargs : `dict`
             Any additional plot arguments that should be used when plotting.
         """
+        import matplotlib.pyplot as plt
         # Check we have a timeseries valid for plotting
         self._validate_data_for_plotting()
 
